"use client"

import { useState, useEffect } from 'react'
import Link from 'next/link'
import { usePathname } from 'next/navigation'
import { motion } from 'framer-motion'
import { Calendar, Users, Clock, LogOut, LogIn } from 'lucide-react'
import { Button } from '@/components/ui/button'
import { useToast } from '@/components/ui/use-toast'

interface User {
  id: string
  email: string
  name?: string
  role: string
}

export default function Header() {
  const [user, setUser] = useState<User | null>(null)
  const [isLoading, setIsLoading] = useState(true)
  const pathname = usePathname()
  const { toast } = useToast()

  useEffect(() => {
    const fetchUser = async () => {
      try {
        const res = await fetch('/api/auth/me')
        if (res.ok) {
          const userData = await res.json()
          setUser(userData)
        } else {
          setUser(null)
        }
      } catch (error) {
        console.error('Error fetching user:', error)
        setUser(null)
      } finally {
        setIsLoading(false)
      }
    }

    fetchUser()
  }, [])

  const handleLogout = async () => {
    try {
      const res = await fetch('/api/auth/logout', {
        method: 'POST',
      })

      if (res.ok) {
        setUser(null)
        toast({
          title: 'Logged out successfully',
          description: 'You have been logged out of your account.',
        })
      }
    } catch (error) {
      console.error('Error logging out:', error)
      toast({
        title: 'Error',
        description: 'Failed to log out. Please try again.',
        variant: 'destructive',
      })
    }
  }

  const navItems = [
    {
      name: 'Book Appointment',
      href: '/',
      icon: <Calendar className="h-4 w-4 mr-2" />,
      showAlways: true,
    },
    {
      name: 'Teachers',
      href: '/admin/teachers',
      icon: <Users className="h-4 w-4 mr-2" />,
      adminOnly: true,
    },
    {
      name: 'Slots',
      href: '/admin/slots',
      icon: <Clock className="h-4 w-4 mr-2" />,
      adminOnly: true,
    },
    {
      name: 'Bookings',
      href: '/admin/bookings',
      icon: <Calendar className="h-4 w-4 mr-2" />,
      adminOnly: true,
    },
  ]

  return (
    <motion.header 
      className="sticky top-0 z-50 w-full border-b bg-background/80 backdrop-blur-sm"
      initial={{ opacity: 0, y: -20 }}
      animate={{ opacity: 1, y: 0 }}
      transition={{ duration: 0.3 }}
    >
      <div className="container flex h-16 items-center justify-between max-w-6xl mx-auto px-4">
        <div className="flex items-center gap-2">
          <Link href="/" className="flex items-center">
            <motion.div
              whileHover={{ scale: 1.05 }}
              className="font-bold text-xl text-primary"
            >
              MyMaktab
            </motion.div>
            <span className="ml-2 text-sm text-muted-foreground">Parents Evening</span>
          </Link>
        </div>
        
        <nav className="flex items-center gap-4">
          {navItems.map((item) => {
            if ((item.adminOnly && user?.role === 'admin') || item.showAlways) {
              return (
                <Link key={item.href} href={item.href}>
                  <Button 
                    variant={pathname === item.href ? "default" : "ghost"} 
                    size="sm"
                    className="flex items-center"
                  >
                    {item.icon}
                    {item.name}
                  </Button>
                </Link>
              )
            }
            return null
          })}
          
          {!isLoading && (
            user ? (
              <Button 
                variant="outline" 
                size="sm" 
                onClick={handleLogout}
                className="flex items-center"
              >
                <LogOut className="h-4 w-4 mr-2" />
                Logout
              </Button>
            ) : (
              <Link href="/login">
                <Button 
                  variant="outline" 
                  size="sm"
                  className="flex items-center"
                >
                  <LogIn className="h-4 w-4 mr-2" />
                  Login
                </Button>
              </Link>
            )
          )}
        </nav>
      </div>
    </motion.header>
  )
}